@@ -3,18 +3,17 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
 #include "config.h"
-
 #include <limits.h>
-#include <common/memory.h>
 #include <ortho/sgraph.h>
 #include <ortho/fPQ.h>
+#include <util/alloc.h>
 
 void
 gsave (sgraph* G)
@@ -42,8 +41,8 @@ void
 initSEdges (sgraph* g, int maxdeg)
 {
     int i;
-    int* adj = N_NEW (6*g->nnodes + 2*maxdeg, int);
-    g->edges = N_NEW (3*g->nnodes + maxdeg, sedge);
+    int* adj = gv_calloc(6 * g->nnodes + 2 * maxdeg, sizeof(int));
+    g->edges = gv_calloc(3 * g->nnodes + maxdeg, sizeof(sedge));
     for (i = 0; i < g->nnodes; i++) {
 	g->nodes[i].adj_edge_list = adj;
 	adj += 6;
@@ -57,11 +56,11 @@ initSEdges (sgraph* g, int maxdeg)
 sgraph*
 createSGraph (int nnodes)
 {
-    sgraph* g = NEW(sgraph);
+    sgraph* g = gv_alloc(sizeof(sgraph));
 
 	/* create the nodes vector in the search graph */
     g->nnodes = 0;
-    g->nodes = N_NEW(nnodes, snode);
+    g->nodes = gv_calloc(nnodes, sizeof(snode));
     return g;
 }
 
