@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -17,35 +17,25 @@
 
 #include "config.h"
 
-/* avoid compiler warnings with template changes in Tcl8.4 */
-/*    specifically just the change to Tcl_CmdProc */
-#define USE_NON_CONST
-
-/* for sincos */
-#define _GNU_SOURCE 1
-
 #include                <sys/types.h>
 #include                <stdbool.h>
 #include                <stdint.h>
 #include                <stdlib.h>
 #include                <string.h>
 
-#include <inttypes.h>
 #include <assert.h>
 #include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
 #include <cgraph/list.h>
+#include <limits.h>
 #include "makecw.h"
 #include <math.h>
 #include <pathplan/pathutil.h>
 #include <pathplan/vispath.h>
 #include <pathplan/tri.h>
+#include "Plegal_arrangement.h"
 #include <tcl.h>
-#include "tclhandle.h"
-
-#ifndef CONST84
-#define CONST84
-#endif
+#include <util/alloc.h>
+#include <util/prisize_t.h>
 
 #if ((TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION >= 6)) || ( TCL_MAJOR_VERSION > 8)
 #else
@@ -63,29 +53,28 @@ typedef struct poly_s {
 
 DEFINE_LIST(polys, poly)
 
-typedef struct vgpane_s {
+/// printf format for TCL handles
+#define HANDLE_FORMAT ("vgpane%" PRISIZE_T)
+
+typedef struct {
     polys_t poly; // set of polygons
     vconfig_t *vc;		/* visibility graph handle */
     Tcl_Interp *interp;		/* interpreter that owns the binding */
     char *triangle_cmd;		/* why is this here any more */
+    size_t index; ///< position within allocated handles list
+    bool valid; ///< is this pane currently allocated?
 } vgpane_t;
 
-#ifdef HAVE_SINCOS
-extern void sincos(double x, double *s, double *c);
-#else
-# define sincos(x,s,c) *s = sin(x); *c = cos(x)
-#endif
+DEFINE_LIST(vgpanes, vgpane_t)
 
-tblHeader_pt vgpaneTable;
-
-extern int Plegal_arrangement(Ppoly_t **polys, size_t n_polys);
+static vgpanes_t vgpaneTable;
 
 static int polyid = 0;		/* unique and unchanging id for each poly */
 
 static poly *allocpoly(vgpane_t * vgp, int id, int npts)
 {
     polys_append(&vgp->poly, (poly){.id = id});
-    poly *rv = polys_at(&vgp->poly, polys_size(&vgp->poly) - 1);
+    poly *rv = polys_back(&vgp->poly);
     rv->boundary.pn = 0;
     rv->boundary.ps = gv_calloc(npts, sizeof(point));
     return rv;
@@ -114,45 +103,41 @@ static int vc_refresh(vgpane_t * vgp)
     return vgp->vc != NULL;
 }
 
-static void dgsprintxy(Tcl_DString * result, int npts, point p[])
-{
+static void dgsprintxy(agxbuf *result, int npts, const point p[]) {
     int i;
-    char buf[20];
 
-    if (npts != 1)
-	Tcl_DStringStartSublist(result);
-    for (i = 0; i < npts; i++) {
-	snprintf(buf, sizeof(buf), "%g", p[i].x);
-	Tcl_DStringAppendElement(result, buf);
-	snprintf(buf, sizeof(buf), "%g", p[i].y);
-	Tcl_DStringAppendElement(result, buf);
+    assert(npts > 1);
+    if (agxblen(result) > 0) {
+	agxbputc(result, ' ');
     }
-    if (npts != 1)
-	Tcl_DStringEndSublist(result);
+    agxbputc(result, '{');
+    const char *separator = "";
+    for (i = 0; i < npts; i++) {
+	agxbprint(result, "%s%g %g", separator, p[i].x, p[i].y);
+	separator = " ";
+    }
+    agxbputc(result, '}');
 }
 
-static void expandPercentsEval(Tcl_Interp * interp,	/* interpreter context */
-			       char *before,	/* Command with percent expressions */
-			       char *r,	/* vgpaneHandle string to substitute for "%r" */
-			       int npts,	/* number of coordinates */
-			       point * ppos	/* Cordinates to substitute for %t */
-    )
-{
-    char *string;
-    Tcl_DString scripts;
+/// @param interp Interpreter context
+/// @param before Command with percent expressions
+/// @param vgcanvasHandle Index to use in "%r" substitution
+/// @param npts Number of coordinates
+/// @param ppos Coordinates to substitute for %t
+static void expandPercentsEval(Tcl_Interp *interp, char *before,
+                               size_t vgcanvasHandle, int npts,
+                               const point *ppos) {
+    agxbuf scripts = {0};
 
-    Tcl_DStringInit(&scripts);
     while (1) {
 	/*
 	 * Find everything up to the next % character and append it to the
 	 * result string.
 	 */
 
-	for (string = before; *string != '\0' && *string != '%'; string++) {
-	    /* Empty loop body. */
-	}
-	if (string != before) {
-	    Tcl_DStringAppend(&scripts, before, string - before);
+	char *string = strchr(before, '%');
+	if (string != NULL) {
+	    agxbput_n(&scripts, before, (size_t)(string - before));
 	    before = string;
 	}
 	if (*before == 0) {
@@ -164,35 +149,29 @@ static void expandPercentsEval(Tcl_Interp * interp,	/* interpreter context */
 
 	switch (before[1]) {
 	case 'r':
-	    Tcl_DStringAppend(&scripts, r, strlen(r));	/* vgcanvasHandle */
+	    agxbprint(&scripts, HANDLE_FORMAT, vgcanvasHandle);
 	    break;
 	case 't':
 	    dgsprintxy(&scripts, npts, ppos);
 	    break;
 	default:
-	    Tcl_DStringAppend(&scripts, before + 1, 1);
+	    agxbputc(&scripts, before[1]);
 	    break;
 	}
 	before += 2;
     }
-    if (Tcl_GlobalEval(interp, Tcl_DStringValue(&scripts)) != TCL_OK)
+    const char *script_value = agxbuse(&scripts);
+    if (Tcl_GlobalEval(interp, script_value) != TCL_OK)
 	fprintf(stderr, "%s while in binding: %s\n\n",
-		Tcl_GetStringResult(interp), Tcl_DStringValue(&scripts));
-    Tcl_DStringFree(&scripts);
+		Tcl_GetStringResult(interp), script_value);
+    agxbfree(&scripts);
 }
 
-static void triangle_callback(void *vgparg, point pqr[])
-{
-    char vbuf[20];
-    vgpane_t *vgp;
-
-    vgp = vgparg;
-
+static void triangle_callback(void *vgparg, const point pqr[]) {
+    vgpane_t *vgp = vgparg;
     if (vgp->triangle_cmd) {
-	snprintf(vbuf, sizeof(vbuf), "vgpane%" PRIu64,
-		((uint64_t)((uintptr_t)vgp - (uintptr_t)vgpaneTable->bodyPtr))
-				 / vgpaneTable->entrySize);
-	expandPercentsEval(vgp->interp, vgp->triangle_cmd, vbuf, 3, pqr);
+	const size_t vgcanvasHandle = vgp->index;
+	expandPercentsEval(vgp->interp, vgp->triangle_cmd, vgcanvasHandle, 3, pqr);
     }
 }
 
@@ -241,7 +220,7 @@ static char *buildBindings(char *s1, const char *s2)
 
 
 /* convert x and y string args to point */
-static int scanpoint(Tcl_Interp * interp, char *argv[], point * p)
+static int scanpoint(Tcl_Interp * interp, const char *argv[], point * p)
 {
     if (sscanf(argv[0], "%lg", &(p->x)) != 1) {
 	Tcl_AppendResult(interp, "invalid x coordinate: \"", argv[0], "\"", NULL);
@@ -254,18 +233,16 @@ static int scanpoint(Tcl_Interp * interp, char *argv[], point * p)
     return TCL_OK;
 }
 
-static point center(point vertex[], int n)
-{
-    int i;
+static point center(point vertex[], size_t n) {
     point c;
 
     c.x = c.y = 0;
-    for (i = 0; i < n; i++) {
+    for (size_t i = 0; i < n; i++) {
 	c.x += vertex[i].x;
 	c.y += vertex[i].y;
     }
-    c.x /= n;
-    c.y /= n;
+    c.x /= (int)n;
+    c.y /= (int)n;
     return c;
 }
 
@@ -281,11 +258,12 @@ static double distance(point p, point q)
 static point rotate(point c, point p, double alpha)
 {
     point q;
-    double beta, r, sina, cosa;
+    double beta, r;
 
     r = distance(c, p);
     beta = atan2(p.x - c.x, p.y - c.y);
-    sincos(beta + alpha, &sina, &cosa);
+    const double sina = sin(beta + alpha);
+    const double cosa = cos(beta + alpha);
     q.x = c.x + r * sina;
     q.y = c.y - r * cosa;	/* adjust for tk y-down */
     return q;
@@ -316,7 +294,7 @@ static bool remove_poly(vgpane_t *vgp, int id) {
 }
 
 static int
-insert_poly(Tcl_Interp * interp, vgpane_t * vgp, int id, char *vargv[],
+insert_poly(Tcl_Interp * interp, vgpane_t * vgp, int id, const char *vargv[],
 	    int vargc)
 {
     poly *np;
@@ -336,29 +314,26 @@ insert_poly(Tcl_Interp * interp, vgpane_t * vgp, int id, char *vargv[],
     return TCL_OK;
 }
 
-static void
-make_barriers(vgpane_t * vgp, int pp, int qp, Pedge_t ** barriers,
-	      int *n_barriers)
-{
-    int j, k, n, b;
+static void make_barriers(vgpane_t *vgp, int pp, int qp, Pedge_t **barriers,
+                          size_t *n_barriers) {
 
-    n = 0;
+    size_t n = 0;
     for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
 	if (polys_get(&vgp->poly, i).id == pp)
 	    continue;
 	if (polys_get(&vgp->poly, i).id == qp)
 	    continue;
-	n = n + polys_get(&vgp->poly, i).boundary.pn;
+	n += polys_get(&vgp->poly, i).boundary.pn;
     }
     Pedge_t *bar = gv_calloc(n, sizeof(Pedge_t));
-    b = 0;
+    size_t b = 0;
     for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
 	if (polys_get(&vgp->poly, i).id == pp)
 	    continue;
 	if (polys_get(&vgp->poly, i).id == qp)
 	    continue;
-	for (j = 0; j < polys_get(&vgp->poly, i).boundary.pn; j++) {
-	    k = j + 1;
+	for (size_t j = 0; j < polys_get(&vgp->poly, i).boundary.pn; j++) {
+	    size_t k = j + 1;
 	    if (k >= polys_get(&vgp->poly, i).boundary.pn)
 		k = 0;
 	    bar[b].a = polys_get(&vgp->poly, i).boundary.ps[j];
@@ -382,34 +357,84 @@ static void appendpoint(Tcl_Interp * interp, point p)
     Tcl_AppendElement(interp, buf);
 }
 
+/// lookup an existing pane
+///
+/// @param panes Collection to search
+/// @param handle Text descriptor of the pane
+/// @return A pointer to the pane or `NULL` if there is no such pane
+static vgpane_t *find_vgpane(vgpanes_t *panes, const char *handle) {
+  assert(panes != NULL);
+  assert(handle != NULL);
+
+  size_t index;
+  if (sscanf(handle, HANDLE_FORMAT, &index) != 1) {
+    return NULL;
+  }
+  if (index >= vgpanes_size(panes)) {
+    return NULL;
+  }
+  vgpane_t *const pane = vgpanes_at(panes, index);
+  if (!pane->valid) {
+    return NULL;
+  }
+
+  return pane;
+}
+
+/// cleanup unused panes where possible
+///
+/// Panes need to have a stable identifier (index) for their lifetime. Thus they
+/// cannot be removed from a `vgpanes_t` when deallocated because removing them
+/// would alter the index of any still-live panes that comes after them.
+/// Instead, panes are marked `->valid = false` when deallocated and then later
+/// removed here.
+///
+/// It is only safe to remove deallocated panes that have no live panes
+/// following them, which is exactly what this function does.
+///
+/// @param panes Collection to sweep
+static void garbage_collect_vgpanes(vgpanes_t *panes) {
+  assert(panes != NULL);
+
+  // shrink list, discarding previously deallocated entries
+  while (!vgpanes_is_empty(panes)) {
+    if (!vgpanes_back(panes)->valid) {
+      (void)vgpanes_pop_back(panes);
+    }
+  }
+
+  // if this left us with none, fully deallocate to make leak checkers happy
+  if (vgpanes_is_empty(panes)) {
+    vgpanes_free(panes);
+  }
+}
+
 /* process vgpane methods */
 static int
 vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
-	  char *argv[])
+	  const char *argv[])
 {
     (void)clientData;
 
-    int vargc, j, n, result;
-    char *s, **vargv, vbuf[30];
-    vgpane_t *vgp, **vgpp;
+    int vargc, result;
+    char vbuf[30];
+    const char **vargv;
+    vgpane_t *vgp;
     point p, q, *ps;
     double alpha, gain;
     Pvector_t slopes[2];
     Ppolyline_t line, spline;
-    int pp, qp;			/* polygon indices for p, q */
     Pedge_t *barriers;
-    int n_barriers;
 
     if (argc < 2) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"",
 			 " ", argv[0], " method ?arg arg ...?\"", NULL);
 	return TCL_ERROR;
     }
-    if (!(vgpp = (vgpane_t **) tclhandleXlate(vgpaneTable, argv[0]))) {
+    if (!(vgp = find_vgpane(&vgpaneTable, argv[0]))) {
 	Tcl_AppendResult(interp, "Invalid handle: \"", argv[0], "\"", NULL);
 	return TCL_ERROR;
     }
-    vgp = *vgpp;
 
     if (strcmp(argv[1], "coords") == 0) {
 	if (argc < 3) {
@@ -425,8 +450,8 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	    /* find poly and return its coordinates */
 	    for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
 		if (polys_get(&vgp->poly, i).id == polyid) {
-		    n = polys_get(&vgp->poly, i).boundary.pn;
-		    for (j = 0; j < n; j++) {
+		    const size_t n = polys_get(&vgp->poly, i).boundary.pn;
+		    for (size_t j = 0; j < n; j++) {
 			appendpoint(interp, polys_get(&vgp->poly, i).boundary.ps[j]);
 		    }
 		    return TCL_OK;
@@ -439,7 +464,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 4) {
 	    result =
 		Tcl_SplitList(interp, argv[3], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -470,11 +495,13 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 
     } else if (strcmp(argv[1], "delete") == 0) {
 	/* delete a vgpane and all memory associated with it */
+	free(vgp->triangle_cmd);
 	if (vgp->vc)
 	    Pobsclose(vgp->vc);
 	polys_free(&vgp->poly);
 	Tcl_DeleteCommand(interp, argv[0]);
-	free(tclhandleFree(vgpaneTable, argv[0]));
+	vgp->valid = false;
+	garbage_collect_vgpanes(&vgpaneTable);
 	return TCL_OK;
 
     } else if (strcmp(argv[1], "find") == 0) {
@@ -488,7 +515,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -521,7 +548,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -565,7 +592,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -589,7 +616,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (vc_refresh(vgp)) {
 	    Pobspath(vgp->vc, p, POLYID_UNKNOWN, q, POLYID_UNKNOWN, &line);
 
-	    for (int i = 0; i < line.pn; i++) {
+	    for (size_t i = 0; i < line.pn; i++) {
 		appendpoint(interp, line.ps[i]);
 	    }
 	}
@@ -606,10 +633,11 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	    Tcl_AppendElement(interp, "triangle");
 	    return TCL_OK;
 	}
+	char *s = NULL;
 	if (strcmp(argv[2], "triangle") == 0) {
 	    s = vgp->triangle_cmd;
 	    if (argc == 4)
-		vgp->triangle_cmd = s = buildBindings(s, argv[3]);
+		vgp->triangle_cmd = buildBindings(s, argv[3]);
 	} else {
 	    Tcl_AppendResult(interp, "unknown event \"", argv[2],
 			     "\": must be one of:\n\ttriangle.", NULL);
@@ -630,7 +658,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	if (argc == 3) {
 	    result =
 		Tcl_SplitList(interp, argv[2], &vargc,
-			      (CONST84 char ***) &vargv);
+			      (const char ***) &vargv);
 	    if (result != TCL_OK) {
 		return result;
 	    }
@@ -652,23 +680,25 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	    return result;
 
 	/* determine the polygons (if any) that contain the endpoints */
-	pp = qp = POLYID_NONE;
+	int pp = POLYID_NONE;
+	int qp = POLYID_NONE;
 	for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
-	    poly *tpp = polys_at(&vgp->poly, i);
-	    if ((pp == POLYID_NONE) && in_poly(tpp->boundary, p))
+	    const poly tpp = polys_get(&vgp->poly, i);
+	    if (pp == POLYID_NONE && in_poly(tpp.boundary, p))
 		pp = (int)i;
-	    if ((qp == POLYID_NONE) && in_poly(tpp->boundary, q))
+	    if (qp == POLYID_NONE && in_poly(tpp.boundary, q))
 		qp = (int)i;
 	}
 
 	if (vc_refresh(vgp)) {
 	    Pobspath(vgp->vc, p, POLYID_UNKNOWN, q, POLYID_UNKNOWN, &line);
+	    size_t n_barriers;
 	    make_barriers(vgp, pp, qp, &barriers, &n_barriers);
 	    slopes[0].x = slopes[0].y = 0.0;
 	    slopes[1].x = slopes[1].y = 0.0;
 	    Proutespline(barriers, n_barriers, line, slopes, &spline);
 
-	    for (int i = 0; i < spline.pn; i++) {
+	    for (size_t i = 0; i < spline.pn; i++) {
 		appendpoint(interp, spline.ps[i]);
 	    }
 	}
@@ -689,7 +719,7 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 		Ppoly_t pp = polys_get(&vgp->poly, i).boundary;
 		point LL, UR;
 		LL = UR = pp.ps[0];
-		for (j = 1; j < pp.pn; j++) {
+		for (size_t j = 1; j < pp.pn; j++) {
 		    p = pp.ps[j];
 		    UR.x = fmax(UR.x, p.x);
 		    UR.y = fmax(UR.y, p.y);
@@ -760,10 +790,10 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	}
 	for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
 	    if (polys_get(&vgp->poly, i).id == polyid) {
-		n = polys_get(&vgp->poly, i).boundary.pn;
+		const size_t n = polys_get(&vgp->poly, i).boundary.pn;
 		ps = polys_get(&vgp->poly, i).boundary.ps;
 		p = center(ps, n);
-		for (j = 0; j < n; j++) {
+		for (size_t j = 0; j < n; j++) {
 		    appendpoint(interp, rotate(p, ps[j], alpha));
 		}
 		return TCL_OK;
@@ -788,9 +818,10 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 	}
 	for (size_t i = 0; i < polys_size(&vgp->poly); i++) {
 	    if (polys_get(&vgp->poly, i).id == polyid) {
-		n = polys_get(&vgp->poly, i).boundary.pn;
+		const size_t n = polys_get(&vgp->poly, i).boundary.pn;
 		ps = polys_get(&vgp->poly, i).boundary.ps;
-		for (j = 0; j < n; j++) {
+		p = center(ps, n);
+		for (size_t j = 0; j < n; j++) {
 		    appendpoint(interp, scale(p, ps[j], gain));
 		}
 		return TCL_OK;
@@ -825,28 +856,28 @@ vgpanecmd(ClientData clientData, Tcl_Interp * interp, int argc,
 }
 
 static int
-vgpane(ClientData clientData, Tcl_Interp * interp, int argc, char *argv[])
+vgpane(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[])
 {
     (void)clientData;
     (void)argc;
     (void)argv;
 
-    char *vbuf = NULL;
-    vgpane_t *vgp = gv_alloc(sizeof(vgpane_t));
-    *(vgpane_t **) tclhandleAlloc(vgpaneTable, &vbuf, NULL) = vgp;
-    assert(vbuf != NULL);
+    const vgpane_t vg = {.interp = interp};
+    vgpanes_append(&vgpaneTable, vg);
+    vgpane_t *const vgp = vgpanes_back(&vgpaneTable);
+    vgp->index = vgpanes_size(&vgpaneTable) - 1;
 
-    vgp->vc = NULL;
-    vgp->poly = (polys_t){0};
-    vgp->interp = interp;
-    vgp->triangle_cmd = NULL;
+    agxbuf buffer = {0};
+    agxbprint(&buffer, HANDLE_FORMAT, vgp->index);
+    const char *const vbuf = agxbuse(&buffer);
 
-    Tcl_CreateCommand(interp, vbuf, vgpanecmd, (ClientData)NULL, NULL);
+    Tcl_CreateCommand(interp, vbuf, vgpanecmd, NULL, NULL);
     Tcl_AppendResult(interp, vbuf, NULL);
-    free(vbuf);
+    agxbfree(&buffer);
     return TCL_OK;
 }
 
+int Tclpathplan_Init(Tcl_Interp *interp);
 int Tclpathplan_Init(Tcl_Interp * interp)
 {
 #ifdef USE_TCL_STUBS
@@ -871,13 +902,12 @@ int Tclpathplan_Init(Tcl_Interp * interp)
 	return TCL_ERROR;
     }
 
-    Tcl_CreateCommand(interp, "vgpane", vgpane, (ClientData)NULL, NULL);
-
-    vgpaneTable = tclhandleInit("vgpane", sizeof(vgpane_t), 10);
+    Tcl_CreateCommand(interp, "vgpane", vgpane, NULL, NULL);
 
     return TCL_OK;
 }
 
+int Tclpathplan_SafeInit(Tcl_Interp *interp);
 int Tclpathplan_SafeInit(Tcl_Interp * interp)
 {
     return Tclpathplan_Init(interp);
